@@ -18,7 +18,7 @@
 #'                   where="CampaignName STARTS_WITH 'A' AND Clicks > 100",
 #'                   start="20140320",
 #'                   end="20140321")
-#' body <- statement(select=c('KeywordText','Clicks','Cost','Ctr'),
+#' body <- statement(select=c('Criteria','Clicks','Cost','Ctr'),
 #'                   report="KEYWORDS_PERFORMANCE_REPORT",
 #'                   where="Clicks > 100",
 #'                   start="20140320",
@@ -49,6 +49,8 @@ statement <- function(select= c("AccountDescriptiveName",
   #
   # Returns:
   #   The statement for the RCurl post.
+  start <- gsub("-","",start)
+  end <- gsub("-","",end)
   selectA <- paste(select,collapse=",")
   
   if(missing(where)){
